@@ -1018,30 +1018,39 @@ class ShanGeTu():
                     y_1 = (i+1)*self.line_size + i*self.cell_size
                     py.draw.rect(self.pic_backgroud,[0,0,0],[x_1,y_1,self.cell_size,self.cell_size])
 
-    def draw_way(self,way_data):
-        self.pic_shangetu = self.pic_backgroud.copy()
+    def draw_way(self,way_data,_2D, y_x_change = False,new_pic = True,color = [0,0,0]):
+        '''
+        '_2D':'标志输入量是否为[x,y]格式',
+        'x_y_change': '调换x——y坐标',
+        'new_pic' : '新建一个背景画线段？默认未True',
+        'color' : '线段的颜色'
+        '''
+        if new_pic == True:
+            self.pic_shangetu = self.pic_backgroud.copy()
         # 转换成二维坐标格式
-        way_data_1 = way_data
-        '''
-        一维格式
-        way_data_1 = []
-        for i in way_data:
-            way_data_1.append([i%self.grid_size,i//self.grid_size])
-        '''
+        if _2D == False:
+            way_data_1 = []
+            for i in way_data:
+                way_data_1.append([i%self.grid_size,i//self.grid_size])
+        else:
+            way_data_1 = way_data
+        if y_x_change == True:
+            for i in range(len(way_data_1)):
+                way_data_1[i][0],way_data_1[i][1] =  way_data_1[i][1],way_data_1[i][0]
         # 画线喽
         for k,i in enumerate(way_data_1):
             try:
                 j = way_data_1[k+1]
             except:
                 return None
-            point_1_y = (i[0]+1)*self.line_size + i[0]*self.cell_size+self.cell_size/2
-            point_1_x = (i[1]+1)*self.line_size + i[1]*self.cell_size+self.cell_size/2
-            point_2_y = (j[0]+1)*self.line_size + j[0]*self.cell_size+self.cell_size/2
-            point_2_x = (j[1]+1)*self.line_size + j[1]*self.cell_size+self.cell_size/2
+            point_1_x = (i[0]+1)*self.line_size + i[0]*self.cell_size+self.cell_size/2
+            point_1_y = (i[1]+1)*self.line_size + i[1]*self.cell_size+self.cell_size/2
+            point_2_x = (j[0]+1)*self.line_size + j[0]*self.cell_size+self.cell_size/2
+            point_2_y = (j[1]+1)*self.line_size + j[1]*self.cell_size+self.cell_size/2
             # 下面两行起到上下翻转的目的
             #point_1_y = self.backgroud_size - point_1_y
             #point_2_y = self.backgroud_size - point_2_y
-            py.draw.line(self.pic_shangetu,[0,0,0],[point_1_x,point_1_y],[point_2_x,point_2_y],2)
+            py.draw.line(self.pic_shangetu,color,[point_1_x,point_1_y],[point_2_x,point_2_y],2)
                 
     def save(self,filename = '栅格图.jpg',reverse = False):
         '''
